@@ -152,11 +152,6 @@ def _should_file_be_generated(path, magic_string):
 
 
 def make_website(apps, repodir, repodict):
-    _ignored, repo_pubkey_fingerprint = extract_pubkey()
-    repo_pubkey_fingerprint_stripped = repo_pubkey_fingerprint.replace(" ", "")
-    link = repodict["address"]
-    link_fingerprinted = ('{link}?fingerprint={fingerprint}'
-                          .format(link=link, fingerprint=repo_pubkey_fingerprint_stripped))
     # do not change this string, as it will break updates for files with older versions of this string
     autogenerate_comment = "auto-generated - fdroid index updates will overwrite this file"
 
@@ -168,6 +163,13 @@ def make_website(apps, repodir, repodict):
 
     if _should_file_be_generated(html_file, autogenerate_comment):
         import qrcode
+
+        _ignored, repo_pubkey_fingerprint = extract_pubkey()
+        repo_pubkey_fingerprint_stripped = repo_pubkey_fingerprint.replace(" ", "")
+        link = repodict["address"]
+        link_fingerprinted = '{link}?fingerprint={fingerprint}'.format(
+            link=link, fingerprint=repo_pubkey_fingerprint_stripped
+        )
         qrcode.make(link_fingerprinted).save(os.path.join(repodir, "index.png"))
         with open(html_file, 'w') as f:
             name = repodict["name"]
@@ -681,9 +683,13 @@ def v2_repo(repodict, repodir, archive):
 
     config = common.load_localized_config(CONFIG_CONFIG_NAME, repodir)
     if config:
-        repo["name"] = config["archive" if archive else "repo"]["name"]
-        repo["description"] = config["archive" if archive else "repo"]["description"]
-        repo["icon"] = config["archive" if archive else "repo"]["icon"]
+        localized_config = config["archive" if archive else "repo"]
+        if "name" in localized_config:
+            repo["name"] = localized_config["name"]
+        if "description" in localized_config:
+            repo["description"] = localized_config["description"]
+        if "icon" in localized_config:
+            repo["icon"] = localized_config["icon"]
 
     repo["address"] = repodict["address"]
     if "mirrors" in repodict:
@@ -769,7 +775,9 @@ def make_v2(apps, packages, repodir, repodict, requestsdict, signer_fingerprints
     # include definitions for "auto-defined" categories, e.g. just used in app metadata
     for category in sorted(categories_used_by_apps):
         if category not in output['repo'][CATEGORIES_CONFIG_NAME]:
-            output['repo'][CATEGORIES_CONFIG_NAME][category] = {"name": {DEFAULT_LOCALE: category}}
+            output['repo'][CATEGORIES_CONFIG_NAME][category] = dict()
+        if 'name' not in output['repo'][CATEGORIES_CONFIG_NAME][category]:
+            output['repo'][CATEGORIES_CONFIG_NAME][category]['name'] = {DEFAULT_LOCALE: category}
     # do not include defined categories if no apps use them
     for category in list(output['repo'].get(CATEGORIES_CONFIG_NAME, list())):
         if category not in categories_used_by_apps:
