@@ -15,11 +15,9 @@ from . import common
 from . import index
 from . import update
 
-options = None
 
-
-def _run_wget(path, urls):
-    if options.verbose:
+def _run_wget(path, urls, verbose=False):
+    if verbose:
         verbose = '--verbose'
     else:
         verbose = '--no-verbose'
@@ -48,8 +46,6 @@ def _run_wget(path, urls):
 
 
 def main():
-    global options
-
     parser = ArgumentParser()
     common.setup_global_opts(parser)
     parser.add_argument(
@@ -93,7 +89,9 @@ def main():
     parser.add_argument(
         "--output-dir", default=None, help=_("The directory to write the mirror to")
     )
-    options = parser.parse_args()
+    options = common.parse_args(parser)
+
+    common.set_console_logging(options.verbose, options.color)
 
     if options.all:
         options.archive = True
@@ -117,7 +115,7 @@ def main():
         )
 
     if fingerprint:
-        config = common.read_config(options)
+        config = common.read_config()
         if not ('jarsigner' in config or 'apksigner' in config):
             logging.error(
                 _('Java JDK not found! Install in standard location or set java_paths!')
@@ -152,10 +150,10 @@ def main():
     if hostname == 'f-droid.org' or (
         ip is not None and hostname in socket.gethostbyname_ex('f-droid.org')[2]
     ):
-        print(
+        logging.error(
             _(
-                'ERROR: this command should never be used to mirror f-droid.org!\n'
-                'A full mirror of f-droid.org requires more than 200GB.'
+                'This command should never be used to mirror f-droid.org! '
+                'A full copy requires more than 600GB.'
             )
         )
         sys.exit(1)
@@ -227,7 +225,7 @@ def main():
                                 _append_to_url_path(section, f[:-4] + '.log.gz')
                             )
 
-        _run_wget(sectiondir, urls)
+        _run_wget(sectiondir, urls, options.verbose)
 
         for app in data['apps']:
             localized = app.get('localized')
@@ -240,7 +238,7 @@ def main():
                         if f:
                             filepath_tuple = components + (f,)
                             urls.append(_append_to_url_path(*filepath_tuple))
-                    _run_wget(os.path.join(basedir, *components), urls)
+                    _run_wget(os.path.join(basedir, *components), urls, options.verbose)
                     for k in update.SCREENSHOT_DIRS:
                         urls = []
                         filelist = d.get(k)
@@ -249,7 +247,11 @@ def main():
                             for f in filelist:
                                 filepath_tuple = components + (f,)
                                 urls.append(_append_to_url_path(*filepath_tuple))
-                            _run_wget(os.path.join(basedir, *components), urls)
+                            _run_wget(
+                                os.path.join(basedir, *components),
+                                urls,
+                                options.verbose,
+                            )
 
         urls = dict()
         for app in data['apps']:
@@ -266,7 +268,12 @@ def main():
                 urls[icondir].append(url)
 
         for icondir in icondirs:
-            _run_wget(os.path.join(basedir, section, icondir), urls[icondir])
+            if icondir in urls:
+                _run_wget(
+                    os.path.join(basedir, section, icondir),
+                    urls[icondir],
+                    options.verbose,
+                )
 
 
 if __name__ == "__main__":
