@@ -20,17 +20,14 @@ from argparse import ArgumentParser
 from . import common
 from . import metadata
 
-options = None
-
 
 def main():
-
     parser = ArgumentParser()
     common.setup_global_opts(parser)
     metadata.add_metadata_arguments(parser)
     options = parser.parse_args()
     metadata.warnings_action = options.W
-    common.read_config(None)
+    common.read_config()
 
     metadata.read_metadata()
 
