@@ -19,20 +19,22 @@ if os.path.exists(cached_file):
     with open(cached_file) as fp:
         data = json.load(fp)
 else:
-    url = 'https://hosted.weblate.org/exports/stats/f-droid/fdroidserver/?format=json'
+    url = 'https://hosted.weblate.org/api/components/f-droid/fdroidserver/statistics/?format=json'
     r = requests.get(url)
     r.raise_for_status()
-    data = r.json()
+    data = r.json()['results']
 
 active = set()
 print('name                               locale   translated approved error-free')
 for locale in sorted(data, key=lambda locale: locale['code']):
-    print('%26s' % locale['name'],
-          '%8s' % locale['code'],
-          '%0.1f%%' % locale['translated_percent'],
-          '%0.1f%%' % locale['approved_percent'],
-          '%0.1f%%' % (100 - locale['failing_percent']),
-          sep='\t')
+    print(
+        '%26s' % locale['name'],
+        '%8s' % locale['code'],
+        '%0.1f%%' % locale['translated_percent'],
+        '%0.1f%%' % locale['approved_percent'],
+        '%0.1f%%' % (100 - locale['failing_percent']),
+        sep='\t',
+    )
     if locale['translated_percent'] >= 90 and locale['failing'] < 5:
         active.add(locale['code'])
 
@@ -79,7 +81,13 @@ with open(manifest_file, 'a') as fp:
         if line:
             fp.write(line)
 
+# first filter duplicates
 subprocess.run(['sort', '-u', '-o', manifest_file, manifest_file])
+# then use a stable sort order
+subprocess.run(
+    ['sort', '--ignore-case', '--stable', '-o', manifest_file, manifest_file],
+    env={'LC_ALL': 'C'},
+)
 
 print('\tIf all else fails, try:')
 print('\tgit checkout -B merge_weblate weblate/master')
