@@ -4,22 +4,23 @@ import logging
 import os
 import shutil
 import tempfile
+import textwrap
 import unittest
 from pathlib import Path
+from unittest import mock
 
-import ruamel.yaml
-
-from .testcommon import mkdtemp
+from .shared_test_code import mkdtemp
 
 import fdroidserver.common
 import fdroidserver.lint
 import fdroidserver.metadata
+from fdroidserver._yaml import config_dump
 
 basedir = Path(__file__).parent
 
 
-class LintTest(unittest.TestCase):
-    '''fdroidserver/lint.py'''
+class SetUpTearDownMixin:
+    """A base class with no test in it for shared setUp and tearDown."""
 
     def setUp(self):
         os.chdir(basedir)
@@ -32,6 +33,10 @@ class LintTest(unittest.TestCase):
     def tearDown(self):
         self._td.cleanup()
 
+
+class LintTest(SetUpTearDownMixin, unittest.TestCase):
+    '''fdroidserver/lint.py'''
+
     def test_check_for_unsupported_metadata_files(self):
         self.assertTrue(fdroidserver.lint.check_for_unsupported_metadata_files())
 
@@ -345,7 +350,7 @@ class LintTest(unittest.TestCase):
     def test_check_categories_from_config_yml(self):
         """In config.yml, categories is a list."""
         os.chdir(self.testdir)
-        Path('config.yml').write_text('categories: [foo, bar]')
+        fdroidserver.common.write_config_file('categories: [foo, bar]\n')
         fdroidserver.lint.config = fdroidserver.common.read_config()
         fdroidserver.lint.load_categories_config()
         self.assertEqual(fdroidserver.lint.CATEGORIES_KEYS, ['foo', 'bar'])
@@ -365,40 +370,41 @@ class LintTest(unittest.TestCase):
 
     def test_lint_config_basic_mirrors_yml(self):
         os.chdir(self.testdir)
-        yaml = ruamel.yaml.YAML(typ='safe')
         with Path('mirrors.yml').open('w') as fp:
-            yaml.dump([{'url': 'https://example.com/fdroid/repo'}], fp)
+            config_dump([{'url': 'https://example.com/fdroid/repo'}], fp)
         self.assertTrue(fdroidserver.lint.lint_config('mirrors.yml'))
 
     def test_lint_config_mirrors_yml_kenya_countryCode(self):
         os.chdir(self.testdir)
-        yaml = ruamel.yaml.YAML(typ='safe')
         with Path('mirrors.yml').open('w') as fp:
-            yaml.dump([{'url': 'https://foo.com/fdroid/repo', 'countryCode': 'KE'}], fp)
+            config_dump(
+                [{'url': 'https://foo.com/fdroid/repo', 'countryCode': 'KE'}], fp
+            )
         self.assertTrue(fdroidserver.lint.lint_config('mirrors.yml'))
 
     def test_lint_config_mirrors_yml_invalid_countryCode(self):
         """WV is "indeterminately reserved" so it should never be used."""
         os.chdir(self.testdir)
-        yaml = ruamel.yaml.YAML(typ='safe')
         with Path('mirrors.yml').open('w') as fp:
-            yaml.dump([{'url': 'https://foo.com/fdroid/repo', 'countryCode': 'WV'}], fp)
+            config_dump(
+                [{'url': 'https://foo.com/fdroid/repo', 'countryCode': 'WV'}], fp
+            )
         self.assertFalse(fdroidserver.lint.lint_config('mirrors.yml'))
 
     def test_lint_config_mirrors_yml_alpha3_countryCode(self):
         """Only ISO 3166-1 alpha 2 are supported"""
         os.chdir(self.testdir)
-        yaml = ruamel.yaml.YAML(typ='safe')
         with Path('mirrors.yml').open('w') as fp:
-            yaml.dump([{'url': 'https://de.com/fdroid/repo', 'countryCode': 'DEU'}], fp)
+            config_dump(
+                [{'url': 'https://de.com/fdroid/repo', 'countryCode': 'DEU'}], fp
+            )
         self.assertFalse(fdroidserver.lint.lint_config('mirrors.yml'))
 
     def test_lint_config_mirrors_yml_one_invalid_countryCode(self):
         """WV is "indeterminately reserved" so it should never be used."""
         os.chdir(self.testdir)
-        yaml = ruamel.yaml.YAML(typ='safe')
         with Path('mirrors.yml').open('w') as fp:
-            yaml.dump(
+            config_dump(
                 [
                     {'url': 'https://bar.com/fdroid/repo', 'countryCode': 'BA'},
                     {'url': 'https://foo.com/fdroid/repo', 'countryCode': 'FO'},
@@ -434,14 +440,16 @@ class LintTest(unittest.TestCase):
 
     def test_lint_invalid_config_keys(self):
         os.chdir(self.testdir)
-        Path('config').mkdir()
-        Path('config/config.yml').write_text('repo:\n  invalid_key: test')
-        self.assertFalse(fdroidserver.lint.lint_config('config/config.yml'))
+        os.mkdir('config')
+        config_yml = fdroidserver.common.CONFIG_FILE
+        with open(f'config/{config_yml}', 'w', encoding='utf-8') as fp:
+            fp.write('repo:\n  invalid_key: test\n')
+        self.assertFalse(fdroidserver.lint.lint_config(f'config/{config_yml}'))
 
     def test_lint_invalid_localized_config_keys(self):
         os.chdir(self.testdir)
         Path('config/en').mkdir(parents=True)
-        Path('config/en/antiFeatures.yml').write_text('NonFreeNet:\n  icon: test.png')
+        Path('config/en/antiFeatures.yml').write_text('NonFreeNet:\n  icon: test.png\n')
         self.assertFalse(fdroidserver.lint.lint_config('config/en/antiFeatures.yml'))
 
     def test_check_certificate_pinned_binaries_empty(self):
@@ -529,3 +537,127 @@ class LintAntiFeaturesTest(unittest.TestCase):
         app = fdroidserver.metadata.App()
         app['Builds'] = [{'antifeatures': ['Ads', 'Tracker']}]
         self.assertEqual(1, len(list(fdroidserver.lint.check_antiFeatures(app))))
+
+
+class ConfigYmlTest(LintTest):
+    """Test data formats used in config.yml.
+
+    lint.py uses print() and not logging so hacks are used to control
+    the output when running in the test runner.
+
+    """
+
+    def setUp(self):
+        super().setUp()
+        self.config_yml = Path(self.testdir) / fdroidserver.common.CONFIG_FILE
+
+    def test_config_yml_int(self):
+        self.config_yml.write_text('repo_maxage: 1\n')
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    @mock.patch('builtins.print', mock.Mock())  # hide error message
+    def test_config_yml_int_bad(self):
+        self.config_yml.write_text('repo_maxage: "1"\n')
+        self.assertFalse(fdroidserver.lint.lint_config(self.config_yml))
+
+    def test_config_yml_str(self):
+        self.config_yml.write_text('sdk_path: /opt/android-sdk\n')
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    def test_config_yml_str_list(self):
+        self.config_yml.write_text('serverwebroot: [server1, server2]\n')
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    def test_config_yml_str_list_of_dicts(self):
+        self.config_yml.write_text(
+            textwrap.dedent(
+                """\
+                serverwebroot:
+                  - url: 'me@b.az:/srv/fdroid'
+                    index_only: true
+                """
+            )
+        )
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    def test_config_yml_str_list_of_dicts_env(self):
+        """serverwebroot can be str, list of str, or list of dicts."""
+        self.config_yml.write_text('serverwebroot: {env: ANDROID_HOME}\n')
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    def test_config_yml_str_env(self):
+        self.config_yml.write_text('sdk_path: {env: ANDROID_HOME}\n')
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    @mock.patch('builtins.print', mock.Mock())  # hide error message
+    def test_config_yml_str_bad(self):
+        self.config_yml.write_text('sdk_path: 1.0\n')
+        self.assertFalse(fdroidserver.lint.lint_config(self.config_yml))
+
+    def test_config_yml_bool(self):
+        self.config_yml.write_text("deploy_process_logs: true\n")
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    @mock.patch('builtins.print', mock.Mock())  # hide error message
+    def test_config_yml_bool_bad(self):
+        self.config_yml.write_text('deploy_process_logs: 2342fe23\n')
+        self.assertFalse(fdroidserver.lint.lint_config(self.config_yml))
+
+    def test_config_yml_dict(self):
+        self.config_yml.write_text("keyaliases: {com.example: '@com.foo'}\n")
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    @mock.patch('builtins.print', mock.Mock())  # hide error message
+    def test_config_yml_dict_bad(self):
+        self.config_yml.write_text('keyaliases: 2342fe23\n')
+        self.assertFalse(fdroidserver.lint.lint_config(self.config_yml))
+
+    @mock.patch('builtins.print', mock.Mock())  # hide error message
+    def test_config_yml_bad_key_name(self):
+        self.config_yml.write_text('keyalias: 2342fe23\n')
+        self.assertFalse(fdroidserver.lint.lint_config(self.config_yml))
+
+    @mock.patch('builtins.print', mock.Mock())  # hide error message
+    def test_config_yml_bad_value_for_all_keys(self):
+        """Check all config keys with a bad value."""
+        for key in fdroidserver.lint.check_config_keys:
+            if key in fdroidserver.lint.bool_keys:
+                value = 'foobar'
+            else:
+                value = 'false'
+            self.config_yml.write_text(f'{key}: {value}\n')
+            self.assertFalse(
+                fdroidserver.lint.lint_config(self.config_yml),
+                f'{key} should fail on value of "{value}"',
+            )
+
+    def test_config_yml_keyaliases(self):
+        self.config_yml.write_text(
+            textwrap.dedent(
+                """\
+                keyaliases:
+                  com.example: myalias
+                  com.foo: '@com.example'
+                """
+            )
+        )
+        self.assertTrue(fdroidserver.lint.lint_config(self.config_yml))
+
+    @mock.patch('builtins.print', mock.Mock())  # hide error message
+    def test_config_yml_keyaliases_bad_str(self):
+        """The keyaliases: value is a dict not a str."""
+        self.config_yml.write_text("keyaliases: '@com.example'\n")
+        self.assertFalse(fdroidserver.lint.lint_config(self.config_yml))
+
+    @mock.patch('builtins.print', mock.Mock())  # hide error message
+    def test_config_yml_keyaliases_bad_list(self):
+        """The keyaliases: value is a dict not a list."""
+        self.config_yml.write_text(
+            textwrap.dedent(
+                """\
+                keyaliases:
+                  - com.example: myalias
+                """
+            )
+        )
+        self.assertFalse(fdroidserver.lint.lint_config(self.config_yml))
